==> jc-1.4.0.tar.gz: java/nio/channels/FileLockInterruptionException.h <==
// public class java.nio.channels.FileLockInterruptionException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3dac9d22a9ff8527 java_nio_channels_FileLockInterruptionException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_nio_channels_FileLockInterruptionException_H_
#define _JC_java_nio_channels_FileLockInterruptionException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_FileLockInterruptionException$sub_refs	_jc_java_nio_channels_FileLockInterruptionException$sub_refs;
typedef struct _jc_java_nio_channels_FileLockInterruptionException$sub_nonrefs	_jc_java_nio_channels_FileLockInterruptionException$sub_nonrefs;
typedef struct _jc_java_nio_channels_FileLockInterruptionException$refs	_jc_java_nio_channels_FileLockInterruptionException$refs;
typedef struct _jc_java_nio_channels_FileLockInterruptionException$nonrefs	_jc_java_nio_channels_FileLockInterruptionException$nonrefs;
typedef struct _jc_java_nio_channels_FileLockInterruptionException$object	_jc_java_nio_channels_FileLockInterruptionException$object;

typedef const struct _jc_java_nio_channels_FileLockInterruptionException$vmethods	_jc_java_nio_channels_FileLockInterruptionException$vmethods;
typedef const struct _jc_java_nio_channels_FileLockInterruptionException$vtable	_jc_java_nio_channels_FileLockInterruptionException$vtable;
typedef const struct _jc_java_nio_channels_FileLockInterruptionException$vtype	_jc_java_nio_channels_FileLockInterruptionException$vtype;

// Constructors
extern void _jc_java_nio_channels_FileLockInterruptionException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_FileLockInterruptionException$object *);

// Virtual methods structure
struct _jc_java_nio_channels_FileLockInterruptionException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_FileLockInterruptionException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_channels_FileLockInterruptionException$vmethods	java_nio_channels_FileLockInterruptionException;
};

// Vtype
struct _jc_java_nio_channels_FileLockInterruptionException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_FileLockInterruptionException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_FileLockInterruptionException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_FileLockInterruptionException$refs {
    _jc_java_nio_channels_FileLockInterruptionException$sub_refs	java_nio_channels_FileLockInterruptionException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_FileLockInterruptionException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_FileLockInterruptionException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_channels_FileLockInterruptionException$sub_nonrefs	java_nio_channels_FileLockInterruptionException;
};

// Object instance structure
struct _jc_java_nio_channels_FileLockInterruptionException$object {
	_jc_java_nio_channels_FileLockInterruptionException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_FileLockInterruptionException$vtype	*vtype;
	_jc_java_nio_channels_FileLockInterruptionException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_FileLockInterruptionException$vtype _jc_java_nio_channels_FileLockInterruptionException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_FileLockInterruptionException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_FileLockInterruptionException$class_object;

#endif	/* _JC_java_nio_channels_FileLockInterruptionException_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/FileLockInterruptionException.h <==
// public class java.nio.channels.FileLockInterruptionException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3dac9d22a9ff8527 java_nio_channels_FileLockInterruptionException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_nio_channels_FileLockInterruptionException_H_
#define _JC_java_nio_channels_FileLockInterruptionException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_FileLockInterruptionException$sub_refs	_jc_java_nio_channels_FileLockInterruptionException$sub_refs;
typedef struct _jc_java_nio_channels_FileLockInterruptionException$sub_nonrefs	_jc_java_nio_channels_FileLockInterruptionException$sub_nonrefs;
typedef struct _jc_java_nio_channels_FileLockInterruptionException$refs	_jc_java_nio_channels_FileLockInterruptionException$refs;
typedef struct _jc_java_nio_channels_FileLockInterruptionException$nonrefs	_jc_java_nio_channels_FileLockInterruptionException$nonrefs;
typedef struct _jc_java_nio_channels_FileLockInterruptionException$object	_jc_java_nio_channels_FileLockInterruptionException$object;

typedef const struct _jc_java_nio_channels_FileLockInterruptionException$vmethods	_jc_java_nio_channels_FileLockInterruptionException$vmethods;
typedef const struct _jc_java_nio_channels_FileLockInterruptionException$vtable	_jc_java_nio_channels_FileLockInterruptionException$vtable;
typedef const struct _jc_java_nio_channels_FileLockInterruptionException$vtype	_jc_java_nio_channels_FileLockInterruptionException$vtype;

// Constructors
extern void _jc_java_nio_channels_FileLockInterruptionException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_FileLockInterruptionException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_FileLockInterruptionException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_FileLockInterruptionException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_channels_FileLockInterruptionException$vmethods	java_nio_channels_FileLockInterruptionException;
};

// Vtype
struct _jc_java_nio_channels_FileLockInterruptionException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_FileLockInterruptionException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_FileLockInterruptionException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_FileLockInterruptionException$refs {
    _jc_java_nio_channels_FileLockInterruptionException$sub_refs	java_nio_channels_FileLockInterruptionException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_FileLockInterruptionException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_FileLockInterruptionException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_channels_FileLockInterruptionException$sub_nonrefs	java_nio_channels_FileLockInterruptionException;
};

// Object instance structure
struct _jc_java_nio_channels_FileLockInterruptionException$object {
	_jc_java_nio_channels_FileLockInterruptionException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_FileLockInterruptionException$vtype	*vtype;
	_jc_java_nio_channels_FileLockInterruptionException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_FileLockInterruptionException$vtype _jc_java_nio_channels_FileLockInterruptionException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_FileLockInterruptionException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_FileLockInterruptionException$class_object;

#endif	/* _JC_java_nio_channels_FileLockInterruptionException_H_ */
